==> ccs-digitalmarketplace-utils-60.1.0.tar.gz: ccs-digitalmarketplace-utils-60.1.0/dmutils/env_helpers.py <==
import os


def get_api_endpoint_from_stage(stage, app='api'):
    """Return the full URL of given API or Search API environment.

    :param stage: environment name. Can be one of 'preview', 'staging',
                  'production' or 'dev' (aliases: 'local', 'development').
    :param app: should be either 'api' or 'search-api'

    """
    stage_domains = {
        'preview': 'https://{}.development.marketplace.team'.format(app),
        'nft': 'https://{}.nft.marketplace.team'.format(app),
        'pre-production': 'https://{}.pre-production.marketplace.team'.format(app),
        'test': 'https://{}.test.marketplace.team'.format(app),
        'uat': 'https://{}.uat.marketplace.team'.format(app),
        'integration': 'https://{}.integration.marketplace.team'.format(app),
        'production': 'https://{}.applytosupply.digitalmarketplace.service.gov.uk'.format(app),
        'sandbox': 'https://{}.sandbox.marketplace.team'.format(app),
    }

    dev_ports = {
        "api": os.getenv("DM_API_PORT", 5000),
        "search-api": os.getenv("DM_SEARCH_API_PORT", 5009),
        "antivirus-api": os.getenv("DM_ANTIVIRUS_API_PORT", 5008),
    }

    if stage in ['local', 'dev', 'development']:
        return 'http://localhost:{}'.format(dev_ports[app])

    return stage_domains[stage]


def get_web_url_from_stage(stage):
    """Return the full URL of given web environment.

    :param stage: environment name. Can be one of 'preview', 'staging',
                  'production' or 'dev' (aliases: 'local', 'development').
    """
    if stage in ['local', 'dev', 'development']:
        return 'http://localhost'

    stage_domains = {
        'preview': 'https://www.development.marketplace.team',
        'nft': 'https://www.nft.marketplace.team',
        'pre-production': 'https://www.pre-production.marketplace.team',
        'test': 'https://www.test.marketplace.team',
        'uat': 'https://www.uat.marketplace.team',
        'integration': 'https://www.integration.marketplace.team',
        'production': 'https://www.applytosupply.digitalmarketplace.service.gov.uk',
        'sandbox': 'https://www.sandbox.marketplace.team',
    }
    return stage_domains[stage]


def get_assets_endpoint_from_stage(stage):
    if stage in ['local', 'dev', 'development']:
        # Static files are not served via nginx for local environments
        raise NotImplementedError()

    return get_api_endpoint_from_stage(stage, 'assets')

==> ccs-digitalmarketplace-utils-60.3.0.tar.gz: ccs-digitalmarketplace-utils-60.3.0/dmutils/env_helpers.py <==
import os


def get_api_endpoint_from_stage(stage: str, app: str = 'api') -> str:
    """Return the full URL of given API or Search API environment.

    :param stage: environment name. Can be one of 'preview', 'staging',
                  'production' or 'dev' (aliases: 'local', 'development').
    :param app: should be either 'api' or 'search-api'

    """
    stage_domains = {
        'preview': 'https://{}.development.marketplace.team'.format(app),
        'nft': 'https://{}.nft.marketplace.team'.format(app),
        'pre-production': 'https://{}.pre-production.marketplace.team'.format(app),
        'test': 'https://{}.test.marketplace.team'.format(app),
        'uat': 'https://{}.uat.marketplace.team'.format(app),
        'integration': 'https://{}.integration.marketplace.team'.format(app),
        'production': 'https://{}.applytosupply.digitalmarketplace.service.gov.uk'.format(app),
        'sandbox': 'https://{}.sandbox.marketplace.team'.format(app),
        'clone': 'https://{}.applytosupply.crowncommercial.gov.uk'.format(app),
    }

    dev_ports = {
        "api": os.getenv("DM_API_PORT", 5000),
        "search-api": os.getenv("DM_SEARCH_API_PORT", 5009),
        "antivirus-api": os.getenv("DM_ANTIVIRUS_API_PORT", 5008),
    }

    if stage in ['local', 'dev', 'development']:
        return 'http://localhost:{}'.format(dev_ports[app])

    return stage_domains[stage]


def get_web_url_from_stage(stage: str) -> str:
    """Return the full URL of given web environment.

    :param stage: environment name. Can be one of 'preview', 'staging',
                  'production' or 'dev' (aliases: 'local', 'development').
    """
    if stage in ['local', 'dev', 'development']:
        return 'http://localhost'

    stage_domains = {
        'preview': 'https://www.development.marketplace.team',
        'nft': 'https://www.nft.marketplace.team',
        'pre-production': 'https://www.pre-production.marketplace.team',
        'test': 'https://www.test.marketplace.team',
        'uat': 'https://www.uat.marketplace.team',
        'integration': 'https://www.integration.marketplace.team',
        'production': 'https://www.applytosupply.digitalmarketplace.service.gov.uk',
        'sandbox': 'https://www.sandbox.marketplace.team',
        'clone': 'https://www.applytosupply.crowncommercial.gov.uk',
    }
    return stage_domains[stage]


def get_assets_endpoint_from_stage(stage: str) -> str:
    if stage in ['local', 'dev', 'development']:
        # Static files are not served via nginx for local environments
        raise NotImplementedError()

    return get_api_endpoint_from_stage(stage, 'assets')
